# Config file for the ecflow package
# Defines the following variables:
#
#  ECFLOW_INCLUDE_DIRS   - include directories
#  ECFLOW_DEFINITIONS    - preprocessor definitions
#  ECFLOW_LIBRARIES      - libraries to link against
#  ECFLOW_FEATURES       - list of enabled features
#  ECFLOW_VERSION        - version of the package
#  ECFLOW_GIT_SHA1       - Git revision of the package
#  ECFLOW_GIT_SHA1_SHORT - short Git revision of the package
#
# Also defines ecflow third-party library dependencies:
#  ECFLOW_TPLS             - package names of  third-party library dependencies
#  ECFLOW_TPL_INCLUDE_DIRS - include directories
#  ECFLOW_TPL_DEFINITIONS  - preprocessor definitions
#  ECFLOW_TPL_LIBRARIES    - libraries to link against

### compute paths

get_filename_component(ECFLOW_CMAKE_DIR "${CMAKE_CURRENT_LIST_FILE}" PATH)

set( ECFLOW_SELF_INCLUDE_DIRS "${ECFLOW_CMAKE_DIR}/../../../include" )
set( ECFLOW_SELF_DEFINITIONS  "" )
set( ECFLOW_SELF_LIBRARIES    "core;nodeattr;node;base;libsimu;libclient;libserver;libharness;ecflow3;viewer" )

set( ECFLOW_TPLS              "" )
set( ECFLOW_TPL_INCLUDE_DIRS  "" )
set( ECFLOW_TPL_DEFINITIONS   "" )
set( ECFLOW_TPL_LIBRARIES     "" )

set( ECFLOW_VERSION           "4.14.0" )
set( ECFLOW_GIT_SHA1          "" )
set( ECFLOW_GIT_SHA1_SHORT    "" )

### export include paths as absolute paths

set( ECFLOW_INCLUDE_DIRS "" )
foreach( path ${ECFLOW_SELF_INCLUDE_DIRS} )
  get_filename_component( abspath ${path} ABSOLUTE )
  list( APPEND ECFLOW_INCLUDE_DIRS ${abspath} )
endforeach()
list( APPEND ECFLOW_INCLUDE_DIRS ${ECFLOW_TPL_INCLUDE_DIRS} )

### export definitions

set( ECFLOW_DEFINITIONS      ${ECFLOW_SELF_DEFINITIONS} ${ECFLOW_TPL_DEFINITIONS} )

### export list of all libraries

set( ECFLOW_LIBRARIES        ${ECFLOW_SELF_LIBRARIES}   ${ECFLOW_TPL_LIBRARIES}   )

### export the features provided by the package

set( ECFLOW_FEATURES    "TESTS" )
foreach( _f ${ECFLOW_FEATURES} )
  set( ECFLOW_HAVE_${_f} 1 )
endforeach()

# Has this configuration been exported from a build tree?
set( ECFLOW_IS_BUILD_DIR_EXPORT OFF )

if( EXISTS ${ECFLOW_CMAKE_DIR}/ecflow-import.cmake )
  set( ECFLOW_IMPORT_FILE "${ECFLOW_CMAKE_DIR}/ecflow-import.cmake" )
  include( ${ECFLOW_IMPORT_FILE} )
endif()

# here goes the imports of the TPL's

include( ${CMAKE_CURRENT_LIST_FILE}.tpls OPTIONAL )

# insert definitions for IMPORTED targets

if( NOT ecflow_BINARY_DIR )

  if( ECFLOW_IS_BUILD_DIR_EXPORT )
    include( "/builddir/build/BUILD/ecFlow-4.14.0-Source/build/ecflow-targets.cmake" OPTIONAL )
  else()
    include( "${ECFLOW_CMAKE_DIR}/ecflow-targets.cmake" OPTIONAL )
  endif()

endif()

# publish this file as imported

set( ECFLOW_IMPORT_FILE ${CMAKE_CURRENT_LIST_FILE} )
mark_as_advanced( ECFLOW_IMPORT_FILE )

# set ecflow_BASE_DIR for final installations or build directories

if( NOT ecflow )
  if( ECFLOW_IS_BUILD_DIR_EXPORT )
    set( ecflow_BASE_DIR /builddir/build/BUILD/ecFlow-4.14.0-Source/build )
  else()
    get_filename_component( abspath ${CMAKE_CURRENT_LIST_DIR}/../../.. ABSOLUTE )
    set( ecflow_BASE_DIR ${abspath} )
  endif()
endif()
